/**
 * Authentication Manager for Playwright MCP Server
 *
 * This module handles authentication for pages that require login.
 * It supports storing and managing authentication configurations,
 * and provides functions for logging in during page capture.
 */
import { AuthConfig } from './types.js';
/**
 * Authentication Manager class
 */
export declare class AuthManager {
    private workspaceRoot;
    private authConfigPath;
    private authConfig;
    constructor(workspaceRoot: string);
    /**
     * Load authentication configuration from file
     */
    private loadAuthConfig;
    /**
     * Save authentication configuration to file
     */
    saveAuthConfig(config: AuthConfig): boolean;
    /**
     * Check if a URL requires authentication
     */
    requiresAuthentication(url: string): boolean;
    /**
     * Get authentication configuration
     */
    getAuthConfig(): AuthConfig;
    /**
     * Create a sample authentication configuration
     */
    createSampleAuthConfig(): boolean;
}
